/* 
 * STATISTICS: TIME GROUP ANALYSIS
 *
 * FOR WORKSPACE MODE
 * 
 * Analysis method based on TGA by Dafydd Gibbon 
 * http://wwwhomes.uni-bielefeld.de/gibbon/tga-3.01.html
 * 
 * Plugin Author: Katarzyna Klessa
 * Plugin Created: 2015-01-28
 * 
 */

using System;
using System.Windows.Forms;
using AnnotationPro.Plugin;
using AnnotationPro.Presentation;
using AnnotationPro.Logic;
using System.IO;
using System.Collections.Generic;
using AnnotationPro.Statistics;
using System.Text;


namespace AnnotationPro.Plugin
{
  public class AnnotationPlugin : IAnnotationPlugin
  {
    const string separator = "\t";
    const string outFilePath = "C:\\Users\\Kasia\\Documents\\SegmentRate.csv";
    const string layerName = "TGA Parameters";

    public void Run(AnnotationEditor editor)
    {
      Annotation annotation = editor.Synchronizer.DataServer.Annotation;

      LayerObject srcLayer = null;
      foreach (LayerObject layer in annotation.Layers) {
        if (layer.Name == layerName) {
          srcLayer = layer;
          break;
        }
      }

      if (srcLayer == null) {
        MessageBox.Show("Layer '" + layerName + "' doesn't exist.", Application.ProductName);
        return;
      }

      editor.Cursor = Cursors.WaitCursor;

      double rateNetto = editor.AnnotationLayers.GetSegmentRateNetto(srcLayer);
      double rateGross = editor.AnnotationLayers.GetSegmentRateGross(srcLayer);

      string outLine = Path.GetFileName(annotation.FilePath) + separator + srcLayer.Name + separator + rateNetto.ToString() + separator + rateGross.ToString() + Environment.NewLine;

	File.AppendAllText(outFilePath, outLine, Encoding.Default);
      editor.Cursor = Cursors.Default;
    }
  }
}